# rlxutils

various utility functions

- verbose `joblib Parallel`
- easy `matplotlib` grid of subplots
- measuring elapsed times of code fragments
- easy execution of shell commands



     pip install git+https://github.com/rramosp/rlxutils
